delicious

package module
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 27, 2020 License: MIT Imports: 6 Imported by: 0

README

delicious

GoDoc

A set of useful utilities in go

Documentation

Index

Constants

const (
	// ONE MILLION
	MILLION uint64 = 1e6
)

Variables

This section is empty.

Functions

func GetTLSConfig

func GetTLSConfig(domain string) (*tls.Config, error)

GetTLSConfig retrives certs from letsencrypt and returns tls config

func RandStr added in v0.0.4

func RandStr(size int) (string, error)

RandStr generates random hex string of given length using crypto/rand

func SetuLimit

func SetuLimit(limit uint64) error

SetuLimit sets the ulimit -n to desired number

Types

This section is empty.

Jump to